@@ -12,8 +12,8 @@ function print_info {
   printf "======================\n"
 }
 
-TIMESTAMP=`date +%y%m%d%H%M`
-GITREF=`git rev-parse --short HEAD`
+TIMESTAMP=$(git log -1 --format="%at" | xargs -I{} date -d @{} +%y%m%d%H%M)
+GITREF=`git rev-parse --short=7 HEAD`
 RELEASE=r${TIMESTAMP}git${GITREF}
 BUILD="devel"
 
